pub struct ManifestHeader {
pub version: u16,
pub entry_count: u32,
pub string_table_size: u32,
pub entrypoint_count: u16,
pub default_entrypoint: u16,
pub lib_dir_count: u16,
pub name_offset: u16,
pub package_id: [u8; 32],
}Fields
version: u16Manifest format version.
entry_count: u32Total number of filesystem entries in the manifest.
string_table_size: u32Size of the string table in bytes.
entrypoint_count: u16Number of entrypoints defined in this package.
default_entrypoint: u16Index of the default entrypoint to use when none is specified.
lib_dir_count: u16Number of library directory paths in the manifest.
name_offset: u16Offset into the string table for the package name.
package_id: [u8; 32]Unique package identifier (BLAKE3 hash).
Implementations